.. Copyright (c) Jupyter Development Team.
.. Distributed under the terms of the Modified BSD License.

Version lifecycle
=================

Each major version of JupyterLab is maintained until
**one year after the following version's first generally available release**.
This does not count alpha, beta, or release candidate (RC) versions.

After the end of maintenance date, no additional releases may be made, not
even to fix security issues.

.. list-table:: Major version lifecycles

  * - Version
    - Release Date
    - End of Maintenance
  * - 1.0.0
    - 28 Jun 2019
    - 28 Feb 2021
  * - 2.0.0
    - 28 Feb 2020
    - 23 Dec 2021
  * - 3.0.0
    - 23 Dec 2020
    - 15 May 2024 (see below)
  * - 4.0.0
    - 15 May 2023
    - *active*

To help with the transition to JupyterLab 4, JupyterLab maintainers may
make additional patch releases to JupyterLab 3 to fix critical issues
until 31 December 2024.
